@@ -4,7 +4,7 @@
 """Specifies the prediction job dataclass."""
 from typing import Optional, Union
 
-from pydantic import BaseModel
+from pydantic.v1 import BaseModel
 
 from openstef.data_classes.model_specifications import ModelSpecificationDataClass
 from openstef.data_classes.split_function import SplitFuncDataClass
@@ -41,8 +41,8 @@ class PredictionJobDataClass(BaseModel):
     If unsure what to pick, choose ``"demand"``.
 
     """
-    horizon_minutes: int
-    """The horizon of the desired forecast in minutes."""
+    horizon_minutes: int = 2880
+    """The horizon of the desired forecast in minutes. Defaults to 2880 minutes (i.e. 2 days)."""
     resolution_minutes: int
     """The resolution of the desired forecast in minutes."""
     lat: float
@@ -67,12 +67,12 @@ class PredictionJobDataClass(BaseModel):
     """Default model specifications"""
     save_train_forecasts: bool = False
     """Indicate wether the forecasts produced during the training process should be saved."""
-    completeness_treshold: float = 0.5
+    completeness_threshold: float = 0.5
     """Minimum fraction of data that should be available for making a regular forecast."""
     minimal_table_length: int = 100
     """Minimum length (in rows) of the forecast input for making a regular forecast."""
-    flatliner_treshold: int = 24
-    """Number of consecutive values that have to be constant to detect a flatliner. """
+    flatliner_threshold_minutes: int = 360
+    """Number of minutes that the load has to be constant to detect a flatliner. """
     depends_on: Optional[list[Union[int, str]]]
     """Link to another prediction job on which this prediction job might depend."""
     sid: Optional[str]
