@@ -3,6 +3,8 @@
 # SPDX-License-Identifier: MPL-2.0
 
 """Openstef custom exceptions."""
+
+
 # Define custom exception
 class NoPredictedLoadError(Exception):
     """No predicted load for given datatime range."""
@@ -42,6 +44,10 @@ class InputDataWrongColumnOrderError(InputDataInvalidError):
     """Wrong column order input data."""
 
 
+class InputDataOngoingZeroFlatlinerError(InputDataInvalidError):
+    """All recent load measurements are zero."""
+
+
 class OldModelHigherScoreError(Exception):
     """Old model has a higher score then new model."""
 
