@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2017-2022 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
+# SPDX-FileCopyrightText: 2017-2023 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
 
@@ -17,6 +17,10 @@ class LGBMOpenstfRegressor(LGBMRegressor, OpenstfRegressor):
     def feature_names(self):
         return self._Booster.feature_name()
 
+    @property
+    def can_predict_quantiles(self):
+        return False
+
     @staticmethod
     def _get_importance_names():
         return {
