@@ -3,7 +3,7 @@
 # SPDX-License-Identifier: MPL-2.0
 import logging
 import os
-from typing import Optional, Union, Tuple
+from typing import Optional, Union
 
 import pandas as pd
 import structlog
@@ -25,7 +25,7 @@ from openstef.model.standard_deviation_generator import StandardDeviationGenerat
 from openstef.model_selection.model_selection import split_data_train_validation_test
 from openstef.validation import validation
 
-DEFAULT_TRAIN_HORIZONS: list[float] = [0.25, 47.0]
+DEFAULT_TRAIN_HORIZONS_HOURS: list[float] = [0.25, 47.0]
 MAXIMUM_MODEL_AGE: int = 7
 
 DEFAULT_EARLY_STOPPING_ROUNDS: int = 10
@@ -80,12 +80,19 @@ def train_model_pipeline(
 
     # Train model with core pipeline
     try:
+        if pj.train_horizons_minutes is None:
+            horizons = DEFAULT_TRAIN_HORIZONS_HOURS
+        else:
+            horizons = [
+                horizon_minutes / 60 for horizon_minutes in pj.train_horizons_minutes
+            ]
+
         model, report, model_specs_updated, data_sets = train_model_pipeline_core(
             pj,
             model_specs,
             input_data,
             old_model,
-            horizons=pj.train_horizons_minutes,
+            horizons=horizons,
         )
     except OldModelHigherScoreError as OMHSE:
         logger.error("Old model is better than new model", pid=pj["id"], exc_info=OMHSE)
@@ -123,9 +130,7 @@ def train_model_pipeline(
         Reporter.write_report_to_disk(report=report, report_folder=report_folder)
 
     # Clean up older models
-    serializer.remove_old_models(
-        experiment_name=str(pj["id"]), artifact_folder=artifact_folder
-    )
+    serializer.remove_old_models(experiment_name=str(pj["id"]))
 
     if pj.save_train_forecasts:
         return data_sets
@@ -136,7 +141,7 @@ def train_model_pipeline_core(
     model_specs: ModelSpecificationDataClass,
     input_data: pd.DataFrame,
     old_model: OpenstfRegressor = None,
-    horizons: Union[list[float], str] = None,
+    horizons: list[float] = DEFAULT_TRAIN_HORIZONS_HOURS,
 ) -> Union[
     OpenstfRegressor,
     Report,
@@ -153,7 +158,7 @@ def train_model_pipeline_core(
         model_specs: Dataclass containing model specifications
         input_data: Input data
         old_model: Old model to compare to. Defaults to None.
-        horizons: horizons to train on in hours.
+        horizons: Horizons to train on in hours, relevant for feature engineering.
 
     Raises:
         InputDataInsufficientError: when input data is insufficient.
@@ -167,12 +172,6 @@ def train_model_pipeline_core(
         - Datasets (tuple[pd.DataFrmae, pd.DataFrame, pd.Dataframe): The train, validation and test sets
 
     """
-    if horizons is None:
-        if pj.train_horizons_minutes is None:
-            horizons = DEFAULT_TRAIN_HORIZONS
-        else:
-            horizons = pj.train_horizons_minutes
-
     logger = structlog.get_logger(__name__)
 
     # Call common pipeline
@@ -231,7 +230,7 @@ def train_pipeline_common(
     pj: PredictionJobDataClass,
     model_specs: ModelSpecificationDataClass,
     input_data: pd.DataFrame,
-    horizons: Union[list[float], str],
+    horizons: list[float],
     test_fraction: float = 0.0,
     backtest: bool = False,
     test_data_predefined: pd.DataFrame = pd.DataFrame(),
@@ -371,12 +370,17 @@ def train_pipeline_step_compute_features(
             input_data = input_data.sort_values(horizons)
     # Validate and clean data
     validated_data = validation.drop_target_na(
-        validation.validate(pj["id"], input_data, pj["flatliner_treshold"])
+        validation.validate(
+            pj["id"],
+            input_data,
+            pj["flatliner_threshold_minutes"],
+            pj["resolution_minutes"],
+        )
     )
     # Check if sufficient data is left after cleaning
     if not validation.is_data_sufficient(
         validated_data,
-        pj["completeness_treshold"],
+        pj["completeness_threshold"],
         pj["minimal_table_length"],
     ):
         raise InputDataInsufficientError(
